@@ -23,4 +23,31 @@
 
 #include <gtk/gtk.h>
 
+typedef struct
+{
+	gchar *countryname;
+	guchar cq;              /* guchar max=255 */
+	guchar itu;
+	gchar *continent;
+	gint latitude;
+	gint longitude;
+	gshort timezone;
+	gchar *px;
+	gchar *exceptions;
+	guint worked;
+	guint confirmed;
+}
+dxcc_data;
+
+struct info
+{
+	gint country;
+	gint cq;
+	gint itu;
+};
+
+void cleanup_dxcc (void);
+gint readctydata (void);
+struct info lookupcountry_by_callsign (gchar * callsign);
+
 void maintext_add (gchar * msg, gint len, gint messagetype);
